#
# spec file for package postgresql
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           postgresql
BuildRequires:  bison flex gettext-devel
BuildRequires:  openldap2-devel openssl-devel pam-devel readline-devel zlib-devel
BuildRequires:  ncurses-devel
%if 0%{?suse_version} > 910
BuildRequires:  krb5-devel libxslt-devel
%endif
Summary:        Basic Clients and Utilities for PostgreSQL
Version:        8.4.17
Release:        1.1
%define pg_minor_version %(echo %version | cut -f1-2 -d.)
License:        BSD3c(or similar)
Group:          Productivity/Databases/Tools
Source0:        postgresql-%version.tar.bz2
Source1:        baselibs.conf
Source2:        postgresql-README.SuSE.de
Source3:        postgresql-README.SuSE.en
Source8:        postgresql-sysconfig
Source9:        postgresql-init
Source15:       postgresql-bashprofile
Source16:       postgresql-firewall
Source17:       postgresql-rpmlintrc
Source99:       postgresql-pl.spec
Patch1:         postgresql-conf.patch
Patch2:         postgresql-regress.patch
Patch3:         postgresql-sle10-timestamptz.patch
PreReq:         postgresql-libs = %pg_minor_version
Url:            http://www.postgresql.org/
Provides:       postgresql = %pg_minor_version
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, and user-defined
types and functions.

This package contains the basic utility and client programs necessary
to maintain and work with local or remote PostgreSQL databases as well
as manual pages for the SQL commands that PostgreSQL supports. Full
HTML documentation for PostgreSQL can be found in the postgresql-docs
package.

%package libs
License:        BSD3c(or similar)
Summary:        Shared Libraries Required for PostgreSQL Clients
Group:          Productivity/Databases/Clients
# bug437293
%ifarch ppc64
Obsoletes:      postgresql-libs-64bit
%endif
#
Provides:       postgresql-libs = %pg_minor_version
PreReq:         sh-utils fileutils

%description libs
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, user-defined types
and functions.

This package provides the essential shared libraries for (almost) any
PostgreSQL client program or interface. You will need to install this
package in order to use any other PostgreSQL package or any clients
that need to connect to a PostgreSQL server.

%package server
License:        BSD3c(or similar)
Summary:        The Programs Needed to Create and Run a PostgreSQL Server
Group:          Productivity/Databases/Servers
PreReq:         %insserv_prereq %fillup_prereq
PreReq:         /usr/sbin/useradd /usr/sbin/groupadd /sbin/chkconfig
PreReq:         /usr/bin/strings /bin/sed
PreReq:         postgresql = %pg_minor_version
Requires:       glibc-locale
Provides:       postgresql-server = %pg_minor_version

%package docs
License:        BSD3c(or similar)
Summary:        HTML Documentation for PostgreSQL
Group:          Productivity/Databases/Tools
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description docs
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, and user-defined
types and functions.

This package contains the HTML documentation for PostgreSQL. The start
page is: file:///usr/share/doc/packages/postgresql/html/index.html .
Manual pages for the PostgreSQL SQL statements can be found in the
postgresql package.

%package contrib
License:        BSD3c(or similar)
Summary:        Contributed Extensions and Additions to PostgreSQL
Group:          Productivity/Databases/Tools
Requires:       postgresql-server = %pg_minor_version

%description contrib
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, and user-defined
types and functions.

The postgresql-contrib package includes extensions and additions that
are distributed along with the PostgreSQL sources, but are not (yet)
officially part of the PostgreSQL core.

Documentation for the modules contained in this package can be found in
/usr/share/doc/packages/postgresql/contrib.

%description server
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, sub-queries, triggers, and user-defined
types and functions.

This package includes the programs needed to create and run a
PostgreSQL server, which will in turn allow you to create and maintain
PostgreSQL databases.

%package devel
License:        BSD3c(or similar)
Summary:        PostgreSQL development header files and libraries
Group:          Productivity/Databases/Tools
Requires:       postgresql-libs = %pg_minor_version

%description devel
PostgreSQL is an advanced object-relational database management system
that supports an extended subset of the SQL standard, including
transactions, foreign keys, subqueries, triggers, and user-defined
types and functions.

This package contains the header files and libraries needed to compile
C applications which will directly interact with a PostgreSQL database
management server and the ECPG Embedded C Postgres preprocessor. You
need to install this package if you want to develop applications in C
which will interact with a PostgreSQL server.


%prep
%setup -q
%patch1
%patch2
# apply the following patch only on SLE10
%if 0%{?suse_version} == 1010
%patch3 -p1
%endif

%build
export CFLAGS="%optflags $SP"
# uncomment the following line to enable the stack protector
# CFLAGS="$CFLAGS -fstack-protector"
%configure \
	--includedir=%_includedir/pgsql \
	--datadir=%_datadir/postgresql \
	--docdir=%_docdir \
	--disable-rpath \
	--enable-nls \
	--enable-thread-safety \
	--enable-integer-datetimes \
	--without-python \
	--without-perl \
	--without-tcl \
	--with-openssl \
	--with-pam \
	--with-ldap \
%if 0%{?suse_version} > 910
	--with-gssapi \
	--with-libxml \
	--with-libxslt \
	--with-krb5 \
%endif
	--with-system-tzdata=/usr/share/zoneinfo
make %{?jobs:-j%jobs} all
make %{?jobs:-j%jobs} -C contrib all
#
%ifnarch %arm
%if 0%{?suse_version} > 910

%check
#
# Run the regression tests.
#
make check || {
  for f in src/test/regress/log/* regression.diffs; do
    if test -f $f; then
	cat $f
    fi
  done
  exit 1
}
%endif
%endif

%install
make DESTDIR=%buildroot install
# Don't ship static libraries, libpgport.a is needed, though.
rm %buildroot/%_libdir/{libecpg,libecpg_compat,libpgtypes,libpq}.a
#
# Install and collect the contrib stuff
#
touch flag; sleep 1 # otherwise we have installed files that are not newer than flag
make DESTDIR=%buildroot -C contrib install
find %buildroot -type f -cnewer flag -printf "/%%P\n" |
     grep -v %_docdir > files.contrib
rm flag
for f in /etc/init.d /var/adm/fillup-templates /usr/sbin \
         /etc/sysconfig/SuSEfirewall2.d/services
do
	install -d %buildroot/$f
done
install -m 755 %{SOURCE9} %buildroot/etc/init.d/postgresql
install -m 644 %{SOURCE8} %buildroot/var/adm/fillup-templates/sysconfig.postgresql
%if 0%{?suse_version} > 1020
install -m 644 %SOURCE16 %buildroot/etc/sysconfig/SuSEfirewall2.d/services/postgresql
%endif
ln -s ../../etc/init.d/postgresql %buildroot/usr/sbin/rcpostgresql
install -d -m 750 %buildroot/var/lib/pgsql
install -d -m 700 %buildroot/var/lib/pgsql/data
install -d -m 700 %buildroot/var/lib/pgsql/backups
sed 's,@LIBDIR@,%_libdir,g' %{SOURCE15} > \
	%buildroot/var/lib/pgsql/.bash_profile
# Backup directory for old version binaries
install -d %buildroot%_libdir/postgresql/backup
cp doc/KNOWN_BUGS doc/MISSING_FEATURES doc/README* COPYRIGHT \
   README HISTORY doc/bug.template %buildroot%_docdir/postgresql
cp -a %SOURCE2 %buildroot%_docdir/postgresql/README.SuSE.de
cp -a %SOURCE3 %buildroot%_docdir/postgresql/README.SuSE.en
for appname in pg_dump pgscripts psql;do
%find_lang $appname-%{pg_minor_version} %{name}.lang
done
for libname in libpq5 ecpglib6;do
%find_lang $libname-%{pg_minor_version} %{name}-libs.lang
done
for serverapp in initdb postgres pg_controldata pg_ctl pg_resetxlog plpgsql;do
%find_lang $serverapp-%{pg_minor_version}  %{name}-server.lang
done
for develapp in pg_config ecpg;do
%find_lang $develapp-%{pg_minor_version} %{name}-devel.lang 
done

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%post server
%fillup_and_insserv

%postun server
%restart_on_update postgresql
%insserv_cleanup
exit 0

%preun server
%stop_on_removal postgresql
exit 0

%pre server
groupadd -g 26 -o -r postgres >/dev/null 2>/dev/null || :
useradd -g postgres -o -r -d /var/lib/pgsql -s /bin/bash \
	-c "PostgreSQL Server" -u 26 postgres 2>/dev/null || :
# Need to make a backup of the server binary if this is an upgrade.
# It will be needed to do a dump of the old version's database.
# All output redirected to /dev/null.
umask 022
if [ -f usr/bin/postgres ]
then
  OLD_VERSION=$(strings usr/bin/postgres | 
    /bin/sed -n '/postmaster (PostgreSQL)/s/.* \([0-9]\+\.[0-9]\+\).*/\1/p')
  if [ "$OLD_VERSION" = "" ]
  then
    OLD_VERSION=$(strings usr/bin/postgres |
      /bin/sed -n 's/^PostgreSQL \([0-9]\+\.[0-9]\+\).*/\1/p')
  fi
  MINOR_VERSION=$(echo %version | sed 's/^\([0-9]\+\.[0-9]\+\).*/\1/')
  BACKUP_DIR=usr/%_lib/postgresql/backup/$OLD_VERSION
  if [ "$OLD_VERSION" != "$MINOR_VERSION" -a ! -f "$BACKUP_DIR" ]
  then
    mkdir -p $BACKUP_DIR
    for f in usr/bin/{postmaster,postgres}; do
      test -f $f && cp -a $f $BACKUP_DIR
    done
  fi
fi

%clean
rm -rf %buildroot
rm -f %my_provides

%files -f %{name}.lang
%defattr(-,root,root)
%doc %_mandir/man7/*
%docdir %_docdir/postgresql
%dir %_docdir/postgresql
%_docdir/postgresql/[[:upper:]]*
%_docdir/postgresql/bug.template
# command line tools
%_bindir/createdb
%doc %_mandir/man1/createdb.1*
%_bindir/clusterdb
%doc %_mandir/man1/clusterdb.1*
%_bindir/createlang
%doc %_mandir/man1/createlang.1*
%_bindir/createuser
%doc %_mandir/man1/createuser.1*
%_bindir/dropdb
%doc %_mandir/man1/dropdb.1*
%_bindir/droplang
%doc %_mandir/man1/droplang.1*
%_bindir/dropuser
%doc %_mandir/man1/dropuser.1*
%_bindir/pg_dump
%doc %_mandir/man1/pg_dump.1*
%_bindir/pg_dumpall
%doc %_mandir/man1/pg_dumpall.1*
%_bindir/pg_restore
%doc %_mandir/man1/pg_restore.1*
%_bindir/psql
%doc %_mandir/man1/psql.1*
%_bindir/vacuumdb
%doc %_mandir/man1/vacuumdb.1*
%_bindir/reindexdb
%doc %_mandir/man1/reindexdb.1.*

%files docs
%defattr(-,root,root)
%docdir %_docdir/postgresql
%dir %_docdir/postgresql
%_docdir/postgresql/html

%files contrib -f files.contrib
%defattr(-,root,root)
%docdir %_docdir/postgresql
%dir %_docdir/postgresql
%_docdir/postgresql/contrib
%dir %_libdir/postgresql
%dir %_datadir/postgresql
%dir %_datadir/postgresql/contrib

%files libs -f %{name}-libs.lang
%defattr(-,root,root)
%_libdir/lib*.so.*

%files server -f %{name}-server.lang
%defattr(-,root,root)
%config /etc/init.d/postgresql
%config /var/adm/fillup-templates/sysconfig.postgresql
%if 0%{?suse_version} > 1020
%config /etc/sysconfig/SuSEfirewall2.d/services/postgresql
%endif
%_sbindir/rcpostgresql
%dir %_libdir/postgresql
%_libdir/postgresql/backup
%_libdir/postgresql/plpgsql.so
%_libdir/postgresql/dict_snowball.so
%_datadir/postgresql/tsearch_data
%_bindir/initdb
%doc %_mandir/man1/initdb.1*
%_bindir/pg_ctl
%doc %_mandir/man1/pg_ctl.1*
%_bindir/pg_controldata
%doc %_mandir/man1/pg_controldata.1*
%_bindir/pg_resetxlog
%doc %_mandir/man1/pg_resetxlog.1*
%_bindir/postgres
%doc %_mandir/man1/postgres.1*
%_bindir/postmaster
%doc %_mandir/man1/postmaster.1*
%dir %_datadir/postgresql
%_datadir/postgresql/timezone*
%_datadir/postgresql/*.*
%_libdir/postgresql/*_and_*.so
%attr(750,postgres,postgres) %dir /var/lib/pgsql
%attr(700,postgres,postgres) %dir /var/lib/pgsql/data
%attr(700,postgres,postgres) %dir /var/lib/pgsql/backups
%attr(640,postgres,postgres) %config(noreplace) /var/lib/pgsql/.bash_profile

%files devel -f %{name}-devel.lang
%defattr(-,root,root)
%_includedir/pgsql
%_bindir/ecpg
%_bindir/pg_config
%_libdir/lib*.so
%_libdir/libpgport.a
%_libdir/postgresql/pgxs
%doc %_mandir/man1/ecpg.1*
%doc %_mandir/man1/pg_config.1*

%changelog
* Fri Apr  5 2013 cs@linux-administrator.com
- update to release 8.4.17
* Sat Feb  9 2013 cs@linux-administrator.com
- update to release 8.4.16
* Sun Dec 16 2012 cs@linux-administrator.com
- update to release 8.4.15
* Mon Sep 24 2012 cs@linux-administrator.com
- update to release 8.4.14
* Sat Aug 18 2012 cs@linux-administrator.com
- update to release 8.4.13
* Mon Sep 26 2011 cs@linux-administrator.com
- update to release 8.4.9
* Tue Oct  5 2010 cs@linux-administrator.com
- update to release 8.4.5
* Thu May 27 2010 max@suse.de
- Security and bugfix release 8.4.4:
  * Enforce restrictions in plperl using an opmask applied to the
    whole interpreter, instead of using Safe.pm. Recent
    developments have convinced us that Safe.pm is too insecure to
    rely on for making plperl trustable. This change removes use of
    Safe.pm altogether, in favor of using a separate interpreter
    with an opcode mask that is always applied. Pleasant side
    effects of the change include that it is now possible to use
    Perl's strict pragma in a natural way in plperl, and that
    Perl's $a and $b variables work as expected in sort routines,
    and that function compilation is significantly
    faster. (CVE-2010-1169)
  * Prevent PL/Tcl from executing untrustworthy code from
    pltcl_modules.  PL/Tcl's feature for autoloading Tcl code from
    a database table could be exploited for trojan-horse attacks,
    because there was no restriction on who could create or insert
    into that table. This change disables the feature unless
    pltcl_modules is owned by a superuser. (However, the
    permissions on the table are not checked, so installations that
    really need a less-than-secure modules table can still grant
    suitable privileges to trusted non-superusers.) Also, prevent
    loading code into the unrestricted "normal" Tcl interpreter
    unless we are really going to execute a pltclu
    function. (CVE-2010-1170)
  * Fix data corruption during WAL replay of ALTER ... SET
    TABLESPACE.  When archive_mode is on, ALTER ... SET TABLESPACE
    generates a WAL record whose replay logic was incorrect. It
    could write the data to the wrong place, leading to
    possibly-unrecoverable data corruption. Data corruption would
    be observed on standby slaves, and could occur on the master as
    well if a database crash and recovery occurred after committing
    the ALTER and before the next checkpoint.
  * Fix possible crash if a cache reset message is received during
    rebuild of a relcache entry. This error was introduced in 8.4.3
    while fixing a related failure.
  * Apply per-function GUC settings while running the language
    validator for the function.
  * This avoids failures if the function's code is invalid without
    the setting; an example is that SQL functions may not parse if
    the search_path is not correct.
  * Do constraint exclusion for inherited UPDATE and DELETE target
    tables when constraint_exclusion = partition. Due to an
    oversight, this setting previously only caused constraint
    exclusion to be checked in SELECT commands.
  * Do not allow an unprivileged user to reset superuser-only
    parameter settings.  Previously, if an unprivileged user ran
    ALTER USER ... RESET ALL for himself, or ALTER DATABASE
    ... RESET ALL for a database he owns, this would remove all
    special parameter settings for the user or database, even ones
    that are only supposed to be changeable by a superuser. Now,
    the ALTER will only remove the parameters that the user has
    permission to change.
  * Avoid possible crash during backend shutdown if shutdown occurs
    when a CONTEXT addition would be made to log entries.  In some
    cases the context-printing function would fail because the
    current transaction had already been rolled back when it came
    time to print a log message.
  * Fix erroneous handling of %%r parameter in recovery_end_command.
    The value always came out zero.
  * Ensure the archiver process responds to changes in
    archive_command as soon as possible.
  * Fix pl/pgsql's CASE statement to not fail when the case
    expression is a query that returns no rows.
  * Update pl/perl's ppport.h for modern Perl versions.
  * Fix assorted memory leaks in pl/python.
  * Handle empty-string connect parameters properly in ecpg.
  * Prevent infinite recursion in psql when expanding a variable
    that refers to itself.
  * Fix psql's \copy to not add spaces around a dot within \copy
    (select ...). Addition of spaces around the decimal point in a
    numeric literal would result in a syntax error.
  * Avoid formatting failure in psql when running in a locale
    context that doesn't match the client_encoding.
  * Fix unnecessary "GIN indexes do not support whole-index scans"
    errors for unsatisfiable queries using contrib/intarray
    operators.
  * Ensure that contrib/pgstattuple functions respond to cancel
    interrupts promptly.
  * Make server startup deal properly with the case that shmget()
    returns EINVAL for an existing shared memory segment.
    This behavior has been observed on BSD-derived kernels
    including OS X. It resulted in an entirely-misleading startup
    failure complaining that the shared memory request size was too
    large.
* Thu Apr 29 2010 max@suse.de
- Use %%configure to pick up the default directories (bnc#600616).
* Tue Mar 16 2010 max@suse.de
- Security and bugfix release 8.4.3.
* Thu Mar 11 2010 max@suse.de
- Disable GSSAPI, XML, kerberos and make check in OBS for SLES9.
* Thu Mar 11 2010 max@suse.de
- Fix build for SLES9
* Tue Feb  9 2010 max@suse.de
- Fix package descriptions.
* Wed Dec 16 2009 max@suse.de
- Security and bugfix release 8.4.2:
  * CVE-2009-4136: Protect against indirect security threats
    caused by index functions changing session-local state. This
    change prevents allegedly-immutable index functions from
    possibly subverting a superuser's session.
  * CVE-2009-4034: Reject SSL certificates containing an embedded
    null byte in the common name (CN) field. This prevents
    unintended matching of a certificate to a server or client
    name during SSL validation.
  * Fix hash index corruption. The 8.4 change that made hash
    indexes keep entries sorted by hash value failed to update the
    bucket splitting and compaction routines to preserve the
    ordering. So application of either of those operations could
    lead to permanent corruption of an index, in the sense that
    searches might fail to find entries that are present. To deal
    with this, it is recommended to REINDEX any hash indexes you
    may have after installing this update.
  * Fix possible crash during backend-startup-time cache
  initialization
  * Avoid crash on empty thesaurus dictionary
  * Prevent signals from interrupting VACUUM at unsafe times. This
  fix prevents a PANIC if a VACUUM FULL is cancelled after it's
  already committed its tuple movements, as well as transient
  errors if a plain VACUUM is interrupted after having truncated
  the table.
  * Fix possible crash due to integer overflow in hash table size
  calculation. This could occur with extremely large planner
  estimates for the size of a hashjoin's result.
  * Fix crash if a DROP is attempted on an internally-dependent
  object.
  * Fix very rare crash in inet/cidr comparisons.
  * Ensure that shared tuple-level locks held by prepared
  transactions are not ignored.
  * Fix premature drop of temporary files used for a cursor that is
  accessed within a subtransaction.
  * Fix memory leak in syslogger process when rotating to a new CSV
  logfile.
  * Fix memory leak in postmaster when re-parsing "pg_hba.conf".
  * Make FOR UPDATE/SHARE in the primary query not propagate into
  WITH queries.
  * Fix bug with a WITH RECURSIVE query immediately inside another
  one.
  * Fix concurrency bug in hash indexes. Concurrent insertions
  could cause index scans to transiently report wrong results.
  * Fix incorrect logic for GiST index page splits, when the split
  depends on a non-first column of the index.
  * Fix wrong search results for a multi-column GIN index with
  fastupdate enabled.
  * Fix bugs in WAL entry creation for GIN indexes. These bugs were
  masked when full_page_writes was on, but with it off a WAL
  replay failure was certain if a crash occurred before the next
  checkpoint.
  * Don't error out if recycling or removing an old WAL file fails
  at the end of checkpoint. It's better to treat the problem as
  non-fatal and allow the checkpoint to complete. Future
  checkpoints will retry the removal. Such problems are not
  expected in normal operation, but have been seen to be caused
  by misdesigned Windows anti-virus and backup software.
  * Ensure WAL files aren't repeatedly archived on Windows. This is
  another symptom that could happen if some other process
  interfered with deletion of a no-longer-needed file.
  * Fix PAM password processing to be more robust.  The previous
  code is known to fail with the combination of the Linux
  pam_krb5 PAM module with Microsoft Active Directory as the
  domain controller. It might have problems elsewhere too, since
  it was making unjustified assumptions about what arguments the
  PAM stack would pass to it.
  * Raise the maximum authentication token (Kerberos ticket) size
  in GSSAPI and SSPI authentication methods.  While the old
  2000-byte limit was more than enough for Unix Kerberos
  implementations, tickets issued by Windows Domain Controllers
  can be much larger.
  * Ensure that domain constraints are enforced in constructs like
  ARRAY[...]::domain, where the domain is over an array type.
  * Fix foreign-key logic for some cases involving composite-type
  columns as foreign keys.
  * Ensure that a cursor's snapshot is not modified after it is
  created. This could lead to a cursor delivering wrong results
  if later operations in the same transaction modify the data the
  cursor is supposed to return.
  * Fix CREATE TABLE to properly merge default expressions coming
  from different inheritance parent tables. This used to work but
  was broken in 8.4.
  * Re-enable collection of access statistics for sequences. This
  used to work but was broken in 8.3.
  * Fix processing of ownership dependencies during CREATE OR REPLACE
  FUNCTION.
  * Fix incorrect handling of WHERE "x"="x" conditions.  In some cases
  these could get ignored as redundant, but they aren't -- they're
  equivalent to "x" IS NOT NULL.
  * Fix incorrect plan construction when using hash aggregation to
  implement DISTINCT for textually identical volatile
  expressions.
  * Fix Assert failure for a volatile SELECT DISTINCT ON expression.
  * Fix ts_stat() to not fail on an empty tsvector value.
  * Make text search parser accept underscores in XML attributes.
  * Fix encoding handling in xml binary input. If the XML header
  doesn't specify an encoding, we now assume UTF-8 by default;
  the previous handling was inconsistent.
  * Fix bug with calling plperl from plperlu or vice versa. An
  error exit from the inner function could result in crashes due
  to failure to re-select the correct Perl interpreter for the
  outer function.
  * Fix session-lifespan memory leak when a PL/Perl function is
  redefined.
  * Ensure that Perl arrays are properly converted to PostgreSQL
  arrays when returned by a set-returning PL/Perl function. This
  worked correctly already for non-set-returning functions.
  * Fix rare crash in exception processing in PL/Python.
  * Fix ecpg problem with comments in DECLARE CURSOR statements.
  * Fix ecpg to not treat recently-added keywords as reserved
  words.  This affected the keywords CALLED, CATALOG, DEFINER,
  ENUM, FOLLOWING, INVOKER, OPTIONS, PARTITION, PRECEDING, RANGE,
  SECURITY, SERVER, UNBOUNDED, and WRAPPER.
  * Re-allow regular expression special characters in psql's \df
  function name parameter.
  * In "contrib/pg_standby", disable triggering failover with a
  signal on Windows. This never did anything useful, because
  Windows doesn't have Unix-style signals, but recent changes
  made it actually crash.
  * Put FREEZE and VERBOSE options in the right order in the VACUUM
  command that "contrib/vacuumdb" produces.
  * Fix possible leak of connections when "contrib/dblink"
  encounters an error.
  * Ensure psql's flex module is compiled with the correct system
  header definitions.  This fixes build failures on platforms
  where --enable-largefile causes incompatible changes in the
  generated code.
  * Make the postmaster ignore any application_name parameter in
  connection request packets, to improve compatibility with
  future libpq versions.
  * Update the timezone abbreviation files to match current reality
  This includes adding IDT to the default timezone abbreviation
  set.
* Wed Dec 16 2009 jengelh@medozas.de
- package documentation as noarch
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Wed Sep 16 2009 crrodriguez@novell.com
- use find_lang to package language files correctly
* Thu Sep 10 2009 max@suse.de
- Security and bugfix release 8.4.1:
  * Fix WAL page header initialization at the end of archive
    recovery. This could lead to failure to process the WAL in a
    subsequent archive recovery.
  * Fix "cannot make new WAL entries during recovery" error.
  * Fix problem that could make expired rows visible after a crash.
    This bug involved a page status bit potentially not being set
    correctly after a server crash.
  * Disallow RESET ROLE and RESET SESSION AUTHORIZATION inside
    security-definer functions. This covers a case that was missed
    in the previous patch that disallowed SET ROLE and SET SESSION
    AUTHORIZATION inside security-definer functions.
    (See CVE-2007-6600)
  * Make LOAD of an already-loaded loadable module into a no-op.
  * Formerly, LOAD would attempt to unload and re-load the module,
    but this is unsafe and not all that useful.
  * Make window function PARTITION BY and ORDER BY items always be
    interpreted as simple expressions. In 8.4.0 these lists were
    parsed following the rules used for top-level GROUP BY and
    ORDER BY lists. But this was not correct per the SQL standard,
    and it led to possible circularity.
  * Fix several errors in planning of semi-joins.  These led to
    wrong query results in some cases where IN or EXISTS was used
    together with another join.
  * Fix handling of whole-row references to subqueries that are
    within an outer join. An example is SELECT COUNT(ss.*) FROM
    ... LEFT JOIN (SELECT ...) ss ON .... Here, ss.* would be
    treated as ROW(NULL,NULL,...) for null-extended join rows,
    which is not the same as a simple NULL. Now it is treated as a
    simple NULL.
  * Fix Windows shared-memory allocation code.  This bug led to the
    often-reported "could not reattach to shared memory" error
    message.
  * Fix locale handling with plperl.
    This bug could cause the server's locale setting to change when
    a plperl function is called, leading to data corruption.
  * Fix handling of reloptions to ensure setting one option doesn't
    force default values for others.
  * Ensure that a "fast shutdown" request will forcibly terminate
    open sessions, even if a "smart shutdown" was already in
    progress.
  * Avoid memory leak for array_agg() in GROUP BY queries.
  * Treat to_char(..., 'TH') as an uppercase ordinal suffix with
  'HH'/'HH12'. It was previously handled as 'th' (lowercase).
  * Include the fractional part in the result of EXTRACT(second)
    and EXTRACT(milliseconds) for time and time with time zone
    inputs.
    This has always worked for floating-point datetime
    configurations, but was broken in the integer datetime code.
  * Fix overflow for INTERVAL 'x ms' when x is more than 2 million
    and integer datetimes are in use.
  * Improve performance when processing toasted values in index
    scans. This is particularly useful for PostGIS.
  * Fix a typo that disabled commit_delay.
  * Output early-startup messages to postmaster.log if the server
    is started in silent mode.  Previously such error messages were
    discarded, leading to difficulty in debugging.
  * Remove translated FAQs. They are now on the wiki. The main FAQ
    was moved to the wiki some time ago.
  * Fix pg_ctl to not go into an infinite loop if postgresql.conf
    is empty.
  * Fix several errors in pg_dump's --binary-upgrade mode.
  * pg_dump --binary-upgrade is used by pg_migrator.
  * Fix contrib/xml2's xslt_process() to properly handle the
    maximum number of parameters (twenty).
  * Improve robustness of libpq's code to recover from errors
    during COPY FROM STDIN.
  * Avoid including conflicting readline and editline header files
    when both libraries are installed.
  * Work around gcc bug that causes "floating-point exception"
    instead of "division by zero" on some platforms.
* Mon Jul 27 2009 poeml@suse.de
- postgresql-8.4.0-sle10-timestamptz.patch added, and applied
  _only_ on SLE10. It fixes a build failure due to a test case that
  seems to be confused by daylight saving time in the time zone
  that the test expects its result (PDT vs. PST). Since this
  failure happened only on SLE10, I assume that the test case isn't
  broken, and some peculiarity on that (rather old now) platform is
  to blame (possibly too old timezone files). Also, the testcase is
  checking correctness when converting timezones > 32 bit, which
  actually seems to work.
* Wed Jul 15 2009 poeml@suse.de
- replace "ident sameuser" with "ident" as auth method for the
  initdb call in the init script, because the former doesn't work
  with PostgreSQL 8.4. With the generated pg_hba.conf, PostgreSQL
  failed to start. Added note to the upgrade READMEs. [bnc#522375]
* Tue Jul  7 2009 max@suse.de
- New major release: 8.4.0
- Improvements include:
  * Windowing Functions
  * Common Table Expressions and Recursive Queries
  * Default and variadic parameters for functions
  * Parallel Restore
  * Column Permissions
  * Per-database locale settings
  * Improved hash indexes
  * Improved join performance for EXISTS and NOT EXISTS queries
  * Easier-to-use Warm Standby
  * Automatic sizing of the Free Space Map
  * Visibility Map (greatly reduces vacuum overhead for
    slowly-changing tables)
  * Version-aware psql (backslash commands work against older
    servers)
  * Support SSL certificates for user authentication
  * Per-function runtime statistics
  * Easy editing of functions in psql
  * New contrib modules: pg_stat_statements, auto_explain, citext,
    btree_gin
* Wed May  6 2009 max@suse.de
- Remove dependency on local posixrules from horology test.
* Mon Mar 23 2009 max@suse.de
- Security release 8.3.7
  * Fixes a vulnerability that allowed remote authenticated
    users to cause a denial of service (stack consumption)
    via mismatched encoding conversion requests.
  * Details of the other bugfixes contained in this and
    previous releases can be found here:
    http://www.postgresql.org/docs/8.3/static/release.html
    /usr/share/doc/packages/postgresql/HISTORY
- Users of GiST indexes should "REINDEX" them after installing
  this update.
- Re-added libpgport.a to the devel package, as some apps require
  it, although it is meant to be internal to the PostgreSQL
  backend.
- Fix removal of leftover files on database startup (bnc#473644).
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Nov  5 2008 max@suse.de
- Bugfix release: 8.3.5
  * Fix GiST index corruption due to marking the wrong index
    entry "dead" after a deletion. This would result in index
    searches failing to find rows they should have found.
  * Fix backend crash when the client encoding cannot represent a
    localized error message.
  * Fix possible crash in bytea-to-XML mapping.
  * Fix possible crash when deeply nested functions are invoked
    from a trigger.
  * Improve optimization of "expression" IN ("expression-list")
    queries.
  * Fix mis-expansion of rule queries when a sub-SELECT appears
    in a function call in FROM, a multi-row VALUES list, or a
    RETURNING list.
  * Fix Assert failure during rescan of an IS NULL search of
    a GiST index.
  * Fix memory leak during rescan of a hashed aggregation plan.
  * Ensure an error is reported when a newly-defined PL/pgSQL
    trigger function is invoked as a normal function.
  * Force a checkpoint before "CREATE DATABASE" starts to copy
    files This prevents a possible failure if files had recently
    been deleted in the source database.
  * Prevent possible collision of relfilenode numbers when moving
    a table to another tablespace with "ALTER SET TABLESPACE".
  * Fix incorrect text search headline generation when single
    query item matches first word of text.
  * Fix improper display of fractional seconds in interval
    values when using a non-ISO datestyle in an
    "--enable-integer-datetimes" build.
  * Make ILIKE compare characters case-insensitively even when
    they're escaped.
  * Ensure "DISCARD" is handled properly by statement logging.
  * Fix incorrect logging of last-completed-transaction time
    during PITR recovery.
  * Ensure SPI_getvalue and SPI_getbinval behave correctly when
    the passed tuple and tuple descriptor have different numbers
    of columns.
  * Fix small memory leak when using libpq's gsslib parameter.
  * Ensure libgssapi is linked into libpq if needed.
  * Fix ecpg's parsing of "CREATE ROLE".
  * Fix recent breakage of pg_ctl restart.
* Thu Sep 25 2008 max@suse.de
- Bugfix release: 8.3.4
- Issues fixed include autovacuum crashes reported by several
  users, two Heap Only Tuple bugs, a foreign key failure
  condition, a too-small lock address space, two Write Ahead Log
  bugs, several planner mistakes, and numerous "corner condition"
  bugs.
* Fri Sep  5 2008 max@suse.de
- New version: 8.3.3 with countless bug fixes over 8.3.1.
- For details, see
  http://www.postgresql.org/docs/8.3/static/release-8-3-2.html ,
  http://www.postgresql.org/docs/8.3/static/release-8-3-3.html ,
  or /usr/share/doc/packages/postgresql/HISTORY .
* Thu Aug 28 2008 cthiel@suse.de
- fix init script
* Mon May 19 2008 schwab@suse.de
- Fix broken configure check.
* Fri May  9 2008 aj@suse.de
- Add baselibs.conf.
* Fri Apr 18 2008 max@suse.de
- Removed static libs from postgresql-devel.
- Removed more old Obsoletes: tags.
- Fixed path to pid file in init script.
- Moved "make check" to %%check section
- Silence some bogus rpmlint warnings
* Thu Apr 10 2008 max@suse.de
- Adopt the 8.3.1 package from Peter Eisentraut's OBS project.
- New features in PostgreSQL 8.3 include:
  * Full text search is integrated into the core database system
  * Support for the SQL/XML standard, including new operators and
    an XML data type
  * Enumerated data types (ENUM)
  * Arrays of composite types
  * Universally Unique Identifier (UUID) data type
  * Add control over whether NULLs sort first or last
  * Updatable cursors
  * Server configuration parameters can now be set on a
    per-function basis
  * User-defined types can now have type modifiers
  * Automatically re-plan cached queries when table definitions
    change or statistics are updated
  * Numerous improvements in logging and statistics collection
  * Support multiple concurrent autovacuum processes, and other
    autovacuum improvements
- Remove old provides/obsoletes tags for way-back package renames.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Jan 10 2008 max@suse.de
- Update to 8.2.6 to fix five security issues:
  - Index Functions Privilege Escalation: CVE-2007-6600
  - Regular Expression Denial-of-Service: CVE-2007-4772,
    CVE-2007-6067, CVE-2007-4769, #329282
  - DBLink Privilege Escalation: CVE-2007-6601, #328403
* Wed Jun  6 2007 max@suse.de
- New version: 8.2.4
- The list of changes between the 8.1 and 8.2 series is too long
  to reproduce here. It can be found under
  /usr/share/doc/packages/postgresql/HISTORY when the postgresql
  package is installed or online at http://www.postgresql.org.
- Splited the postgresql-pl package into individual packages for
  PL/Perl, PL/Python and PL/Tcl.
- Added a config file for SuSEfirewall2 (#247370).
* Thu Mar 29 2007 rguenther@suse.de
- Add bison, flex and zlib-devel BuildRequires.
* Tue Oct 17 2006 max@suse.de
- New patchlevel release: 8.1.5
- Disallow aggregate functions in "UPDATE" commands, except within
  sub-SELECTs. The behavior of such an aggregate was unpredictable,
  and in 8.1.X could cause a crash, so it has been disabled.
- Fix core dump when an untyped literal is taken as ANYARRAY.
- Fix core dump in duration logging for extended query protocol when
  a "COMMIT" or "ROLLBACK" is executed.
- Fix mishandling of AFTER triggers when query contains a SQL function
  returning multiple rows.
- Fix "ALTER TABLE ... TYPE" to recheck NOT NULL for USING clause.
- Fix string_to_array() to handle overlapping matches for the
  separator string.
- Fix to_timestamp() for AM/PM formats.
- Fix autovacuum's calculation that decides whether "ANALYZE" is
  needed.
- Fix corner cases in pattern matching for psql's \d commands.
- Fix index-corrupting bugs in /contrib/ltree.
- Numerous robustness fixes in ecpg.
- Fix backslash escaping in /contrib/dbmirror.
- Minor fixes in /contrib/dblink and /contrib/tsearch2.
- Efficiency improvements in hash tables and bitmap index scans.
* Wed May 24 2006 max@suse.de
- Update to 8.1.4 to fix SQL injection vulnerabilities
  (bug #177931, CVE-2006-2313, CVE-2006-2314).
- Added a new postgresql-SECURITY-NOTICE file with an FAQ that
  explains the issues.
* Mon Feb 13 2006 max@suse.de
- New version: 8.1.3 (#150376).
- Relaxed dependencies between subpackages to simplify future
  updates.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 max@suse.de
- Moved from logrotate to PostgreSQL's own log rotation facility.
- Log files are now located under /var/lib/pgsql/data/pg_log .
- Improved error reporting on test suite failures.
* Thu Dec 22 2005 max@suse.de
- New version: 8.1.1
* Fri Jun 17 2005 max@suse.de
- Removed bogus %%patch3
* Thu Jun  2 2005 max@suse.de
- Added postgresql-CAN-2005-1409-1410-fix.sh for fixing existing
  installations, and referred to it in the SECURITY-NOTICE.
* Tue May 17 2005 max@suse.de
- Added postgresql-SECURITY-NOTICE to describe the manual actions
  that are needed to apply the bugfixes from 8.0.3 to existing
  installations.
* Tue May 10 2005 max@suse.de
- New patch release: 8.0.3
- Fixes bug #82869, CAN-2005-1410, and CAN-2005-1409
- Obsoletes postgresql-CAN-2005-0247.patch
* Mon Apr 11 2005 max@suse.de
- New patch release: 8.0.2
* Mon Apr  4 2005 uli@suse.de
- hardwire thread safety to yes (test may hang QEMU)
* Fri Apr  1 2005 uli@suse.de
- ignore regressions on ARM
* Wed Mar 16 2005 max@suse.de
- Prevent the wrapper libs from ending up in the provides list.
* Mon Mar 14 2005 max@suse.de
- Added postgresql-CAN-2005-0247.patch to fix bug #65692.
* Fri Mar 11 2005 max@suse.de
- Added some wrapper libs so that old postmaster binaries, back
  to at least 8.1/SLES8 can still be started.
- Extended the init script to use the wrapper libs when needed.
- Setting a senseful umask when creating the postmaster backups
  in %%pre.
* Mon Feb  7 2005 max@suse.de
- New patch release: 8.0.1
- Fixes a vulnerability in the LOAD command.
* Wed Jan 19 2005 max@suse.de
- Update to the final 8.0.0 release.
* Wed Dec 22 2004 max@suse.de
- New version: 8.0.0rc2
* Fri Dec 10 2004 max@suse.de
- New version: 8.0.0rc1
- Recoded README.SuSE.de to UTF-8.
* Fri Dec  3 2004 max@suse.de
- New version: 8.0.0beta5
* Thu Nov 18 2004 ro@suse.de
- use kerberos-devel-packages
* Mon Sep  6 2004 max@suse.de
- Created a separate spec file for the postgresql-pl subpackage.
* Fri Aug 20 2004 max@suse.de
- New version: 7.4.5.
* Thu Jul 15 2004 max@suse.de
- New version: 7.4.3.
* Mon May 24 2004 max@suse.de
- Changed dependency of -devel from the main package to -libs
  (Bug #40922).
* Mon Apr  5 2004 max@suse.de
- Added postgresql-regression.patch to prevent test failures
  during summertime/wintertime changes.
* Thu Mar 11 2004 max@suse.de
- New patch release: 7.4.2
* Fri Jan 16 2004 kukuk@suse.de
- Add pam-devel to neededforbuild
* Mon Jan 12 2004 max@suse.de
- New version: 7.4.1
- Write timestamps to /var/log/postgresql by default.
* Thu Dec 18 2003 max@suse.de
- Package the backend headers as well (make install-all-headers),
  because they are needed for server-side modules written in C.
* Tue Nov 18 2003 max@suse.de
- Install pg_config_manual.h and port.h, because they are needed
  by c.h (postgresql-include.patch).
* Mon Nov 17 2003 max@suse.de
- New version: 7.4. For details see
  http://www.postgresql.org/docs/7.4/static/release.html, or
  /usr/share/doc/packages/postgresql/html/release.html
- Overhauled and simplified the spec file.
- Building with Kerberos-Support.
- Building thread-safe client libraries.
- Architecture-dependent tweaks for the testsuite are not needed
  anymore.
- Better detection for embedded Python build options.
* Mon Oct 20 2003 schwab@suse.de
- Fix last change.
* Sat Oct 18 2003 adrian@suse.de
- ignore minor mis-calculation on mips
- build as user
* Tue Sep 23 2003 max@suse.de
- Fixed version detection in the pre script of the server package.
  (#31570)
- Ignore errors from stop_on_removal (#31607).
* Mon Sep 15 2003 max@suse.de
- Activated the patch, that fixes dbf2pg (#27427). The patch was
  added to the package before, but accidentally didn't get applied.
- Improved handling of old versions of the backend (#27114).
- Stopping the server before uninstallation and restarting it
  after update (#29038).
* Fri Aug 29 2003 mcihar@suse.cz
- python bindings require same python version as it was built with
* Thu Aug 14 2003 max@suse.de
- Added ServiceRestart to sysconfig template.
* Thu Aug 14 2003 ro@suse.de
- fixed chown usage in init-script
* Mon Aug  4 2003 max@suse.de
- New version: 7.3.4.
- Adopted postgresql-multilib.patch from the official PostgreSQL
  RPMs. This obsoletes postgresql-lib64.patch.
- Use test-and-set locks for x86_64 instead of slow semaphores.
  (postgresql-x86_64.patch, Bug #27308)
- make use of %%jobs for parallel builds.
- Fix ownership of /etc/logrotate.d/postgresql (Bug #28431).
- Changed the default locale for the server to "C" to avoid a hard
  dependency to glibc-locale (bug #28338).
- Enabled charset conversion for dbf2pg (Bug #27427).
* Wed Jul 16 2003 meissner@suse.de
- fix hanging builds by another rework of the ppc64
  locking. Apparently we need to do exact stcwx. ; bne ; isync
  sequences to stay correct.
* Tue Jun 24 2003 meissner@suse.de
- Fixed the ppc/ppc64 locking, isync was at the wrong
  position. Replaced full sync by lwsync. slock_ts can
  be 32bit on ppc64 too, we just use lwarx/stwcx which
  handle 32bit components.
* Tue Jun  3 2003 max@suse.de
- New version: 7.3.3.
- Remove unpackaged files.
- pg_hba.conf: only allow local connections from the same user
  by default.
* Fri Mar 14 2003 max@suse.de
- Fixed generation of sql files in contrib, and really install the
  contrib stuff instead of just copying over the source tree
  (Bug #25323, postgresql-contrib.patch).
- Fixed the file-list of the server package.
* Wed Mar 12 2003 max@suse.de
- Fixed a typo in the init script (Bug #25115).
* Thu Mar  6 2003 max@suse.de
- Add support for LSB compatible exit codes for start and stop
  to pg_ctl (postgresql-lsb.patch).
- Use pg_ctl instead of startproc/killproc in init script, because
  it waits until the server is completely fired up or shut down.
  (Bug #24395)
- Removed the libpq.so.2.0 link from the package, because it got
  removed by ldconfig after installation anyways (Bug #24557).
* Tue Feb 25 2003 max@suse.de
- Mark manpages as documentation.
- Create the backup directory during install.
* Mon Feb 24 2003 max@suse.de
- Make a backup of the server binaries during update, and use the
  old server as long as the data files are still in the old format.
* Thu Feb  6 2003 max@suse.de
- New patch release 7.3.2 which fixes several serious bugs.
  See HISTORY for details.
* Tue Jan 28 2003 max@suse.de
- Added metadata for the sysconfig editor.
* Mon Jan 20 2003 max@suse.de
- New version: 7.3.1
- Removed old update scripts, because they don't work anymore.
* Thu Jan 16 2003 bg@suse.de
- Changed the expected test results for hppa to the correct files
* Fri Nov 29 2002 max@suse.de
- New version 7.3.
- Compiling with PAM support.
- Client libraries (perl, tcl, odbc, pgeasy, pq++) have been
  taken out of the PostgreSQL core distribution and will be
  built as separate packages in the future.
- The plperl subpackage has been renamed to pl, and now contains
  PL/Perl, PL/Python, and PL/Tcl.
* Fri Sep 13 2002 max@suse.de
- Added circle_poly-overrun.patch to fix a couple of
  buffer overruns.
* Thu Sep 12 2002 max@suse.de
- Corrected symlink /usr/lib/libpq.so.2.0 [#19490].
- Fixed ownership of /var/lib/pgsql [#19523].
* Fri Sep  6 2002 max@suse.de
- Recovered time stamps of source files and patches.
* Mon Sep  2 2002 max@suse.de
- Updated to patch release 7.2.2 which fixes some security holes.
- Essential diff between 7.2.1 and 7.2.2 is included.
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Mon Aug 19 2002 kukuk@suse.de
- Fix requires egenix-mx-base -> python-egenix-mx-base
* Thu Aug 15 2002 ro@suse.de
- don't chmod 644 to directories
* Wed Aug 14 2002 ro@suse.de
- added "missingok" to logrotate config
* Fri Aug  9 2002 max@suse.de
- Removed sysconfig from neededforbuild.
- Using x-devel-packages instead of xf86.
* Thu Aug  8 2002 max@suse.de
- Removed support for older SuSE versions.
- Moved log file cration from %%post to rcpostgresql.
- Changed group for /etc/logrotate.d/postgresql.
* Mon Aug  5 2002 max@suse.de
- Enabled the plperl subpackage.
* Tue Jul 30 2002 max@suse.de
- Fixed regression tests for ppc64.
* Fri Jul 12 2002 max@suse.de
- Re-enabled the regression tests.
- Running test suite as nobody.
- Adjusted ppc and lib64 patch to the scheme of the other
  platform patches.
- Better test-and-set assembler code for s390 and s390x.
- Creating postgres user and group during RPM installation.
* Tue Jun 18 2002 meissner@suse.de
- use the powerpc assembler tas() for ppc64 too with adjusted assembler
  names.
* Fri May 24 2002 max@suse.de
- New minor release: 7.2.1
- Temporaryly disabled the regression tests due to changes to
  mktime() that caused some tests to fail.
* Fri May 24 2002 ke@suse.de
- postgresql-python requires egenix-mx-base (DateTime) [# 14745].
* Wed May 22 2002 meissner@suse.de
- %%_lib fixes for lib64 architectures. Now fails at the same point as i386.
* Wed Mar 20 2002 max@suse.de
- Changed postgresql package to PreReq postgresql-libs instead of
  postgresql-lib which is obsolete.
* Fri Mar  8 2002 poeml@suse.de
- add missing / before %%_lib, fixing the preinstall script of -libs
  subpackage
* Wed Mar  6 2002 max@suse.de
- Fixed test-and-set assembler code for s390x.
- Made finding of perl and python site-paths more portable.
- Fixed detection of SuSE dist for older releases.
- Some more %%_libdir corrections.
- Using -fPIC for building shared libs on all architectures.
- Leaving out tk and python subpackages if tk and python
  are not OK.
* Mon Mar  4 2002 max@suse.de
- Fixed creation of pkgIndex.tcl
- Removed some python stuff from the spec file that is now part of
  PostgreSQL's build system.
- Removed unneeded executable permissions from a couple of files.
* Wed Feb 13 2002 max@suse.de
- added support for logrotate
- changed sysconfig stuff and init script to run on both
  schemes (<=7.3 and >=8.0).
* Tue Feb  5 2002 max@suse.de
- Updated to 7.2 final.
- See the file /usr/share/doc/packages/postgresql/HISTORY
  for changes and incompatibilities since version 7.1.x.
- Adapted the init script to match the new versions of killproc
  and PostgreSQL.
* Mon Jan 28 2002 max@suse.de
- Updated to 7.2rc2
- Removed temporary header fix.
- Added a patch for autoconf-2.52 (disabled by derfault).
- Added english version of README.SuSE
* Tue Jan 22 2002 max@suse.de
- removed os.h. It's not needed anymore.
- fixed locations of internal header files (temporary).
- postgresql-python now obsoletes pygresql.
- updated the files lists.
* Mon Jan 21 2002 max@suse.de
- New version 7.2b5
* Tue Dec 18 2001 max@suse.de
- Changed spec file to make use of %%{_libdir} where appropriate.
* Mon Dec 17 2001 max@suse.de
- Removed the START_POSTGRES variable from the fillup template
  and changed init script, and spec file to the new scheme.
- Moved the remaining variables from /etc/rc.config to
  /etc/sysconfig/postgresql.
* Wed Sep 12 2001 max@suse.de
- New version (patch release): 7.1.3
  The ChangeLog says:
  - Remove unused WAL segements of large transactions (Tom)
  - Multiaction rule fix (Tom)
  - Pl/pgSQL memory allocation fix (Jan)
  - VACUUM buffer fix (Tom)
  - Regression test fixes (Tom)
  - pg_dump fixes for GRANT/REVOKE/comments on views,
    user-defined types (Tom)
  - Fix subselects with DISTINCT ON or LIMIT (Tom)
  - BEOS fix
  - Disable COPY TO/FROM a view (Tom)
  - Cygwin build (Jason Tishler)
- Fixed bug in init script.
  It needed a file that comes only with postgresql-devel
- Better Patch for PgTcl. It now sets the client encoding to
  UNICODE (PostgreSQL's name for UTF-8) for Tcl versions >= 8.1
  instead of using Tcl's conversion functions to get the correct
  string representation.
- Added README.SuSE (only german, so far)
- Some minor typo fixes in the spec file.
* Mon Aug 27 2001 utuerk@suse.de
- removed postgresql.conf (now provided by susehelp)
* Mon Jul 23 2001 max@suse.de
- Fixed %%pre and %%post scripts for YaST.
* Thu Jul 19 2001 max@suse.de
- fixed regression tests for SPARC32.
- fixed init script to warn about incompatible data files.
- added patch for Pgtcl to use UTF8 for internal string
  representation if compiled with Tcl >= 8.1 .
- added pkgIndex.tcl to allow dynamic loading of Pgtcl using
  Tcl's package mechanism.
* Wed Jul 11 2001 max@suse.de
- fixed regression test to succeed on PPC with glibc-2.2.3 .
* Tue Jul 10 2001 max@suse.de
- new version: 7.1.2
- packages again based on the official PostgreSQL RPMs.
- architecture patches are no longer needed.
- running the regression tests as part of the build process to
  ensure that only correctly built binaries get packed in.
- new subpackages: contrib, doc
- renamed subpackage lib to libs to conform to the official RPMs
- ToDo: (semi)automatic conversion for updates
  from versions prior 7.1.
* Mon May  7 2001 mfabian@suse.de
- bzip2 sources
* Fri Apr 27 2001 max@suse.de
- updated the init script to be more LSB compliant according to
  the current /etc/init.d/skeleton.
* Thu Apr 12 2001 max@suse.de
- fix for deprecated declarations in readline 4.2.
- fixed permissons of some shared objects for the backend.
- recovered timestamps of sources.
* Wed Apr 11 2001 utuerk@suse.de
- added postgresql.conf for susehelp
* Thu Mar 22 2001 ro@suse.de
- added split-aliases as provides
* Wed Mar 21 2001 poeml@suse.de
- 7.0.* does not work on PPC unless compiled with -O0 (7.1 will)
* Wed Mar  7 2001 max@suse.de
- added xshared and xdevel to neededforbuild
  because X is no longer in the default buildsystem.
* Thu Feb 22 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Wed Jan 24 2001 max@suse.de
- added missing "Provides:" entries to specfile.
* Mon Jan 15 2001 max@suse.de
- dropping the locale environment vars from the init script
  as workarround for a locale related bug in the backend.
  It shows up when the regression test runs on a backend that
  has e.g. LC_CTYPE=de_DE .
* Wed Nov 29 2000 max@suse.de
- new version: 7.0.3
- spec file is based on Lamar Owen's source RPM of
  PostgreSQL-7.0.3 for SuSE Linux 7.0
- renamed the whole package
    postgres -> postgresql
    pg_lib   -> postgresql-lib
    pg_serv  -> postgresql-serv
    pg_devel -> postgresql-devel
    pg_tcl   -> postgresql-tcl
    pg_tk    -> postgresql-tk
    pg_odbc  -> postgresql-odbc
    pg_jdbc  -> postgresql-jdbc
    pg_pyth  -> postgresql-python
    pg_perl  -> postgresql-perl
    pg_test  -> postgresql-test
- renamed some files and scripts from *postgres* to *postgresql*
- moved to the LSB-compliant init scheme
- moved database initialisation from SuSEconfig.postgres
  into the init script
- changed postgresql-python to use Python2.0 instead of 1.5
* Sat Oct 28 2000 kukuk@suse.de
- Add python-devel to need for build
* Mon Oct 23 2000 bk@suse.de
- integrated change from max:
- changed /sbin/init.d/postgres and SuSEconfig.postgres
  to work arround YaST that quotes the value of POSTGRES_DATADIR
  in /etc/rc.config when it gets changed.
* Mon Sep 11 2000 fober@suse.de
- made postgres run&autobuild on s390:
- src/include/port/linux.h, src/include/storage/s_lock.h:
  s390-assembler test-and-set (thanks to Andreas Jaeger)
- src/template/.similar, src/template/linux_s390:
  created linux_s390-Template from linux_ppc.
  TODO: is -O0 really needed?
- regression test passes (with minor deviations in floating point
  arithmetics)
  TODO: the regression test will not run out of the box as we install
  it.  this is the missing piece, either in postgres-source or in
  .spec
  [#] missing files
  cd $BUILD_ROOT/usr/src/packages/BUILD/postgresql-7.0.2/;
  cp -avP src/backend/*.h $RPM_BUILD_ROOT/usr/lib/pgsql
  cp -avP src/include $RPM_BUILD_ROOT/usr/lib/pgsql
  cp -avP src/Makefile.port $RPM_BUILD_ROOT/usr/lib/pgsql
  cp -avP src/Makefile.global $RPM_BUILD_ROOT/usr/lib/pgsql
  [#] directory structure
  cd $RPM_BUILD_ROOT/usr/lib/pgsql
  mkdir src
  mv test src
  ln -s src/test .
* Mon Aug 28 2000 max@suse.de
- changed installation order to fix bug #3802
* Mon Jul  3 2000 max@suse.de
- Disabled fcntl(F_SETLK) on the postmaster socket to work arround
  a kernel bug in Linux <= 2.2.16.
- New subpackage: pg_lib contains the shared libs for C and C++.
* Thu Jun 29 2000 schwab@suse.de
- Fix spinlocks for ia64.
- Reenable ia64 patch on the other architectures.
* Wed Jun 28 2000 max@suse.de
- disabled the ia64 patch when building for other architectures
- database unload+reload on updates works now
- moved some script and config files out of the diff into
  source files of their own.
- template database creation moved from init script into SuSEconfig
- some minor cleanups
* Tue Jun 20 2000 schwab@suse.de
- Add support for ia64.
* Fri Jun  9 2000 max@suse.de
- New version: 7.0.2.
- Re-made the whole package based on the original PostgreSQL RPM.
- There is still a little work needed for clean updates from
  PostgreSQL 6.x to 7.0.x
- Heavy testing needed before SuSE Linux 7.0.
* Sun Apr  9 2000 bk@suse.de
- added suse update config macro
- added automake to list of packages needed for building postgres
* Thu Feb 10 2000 ke@suse.de
- add more source files from the official PostgreSQL package.
- start to apply patches from there.
- start to cleanup the spec file.
- start to resolve bug #1948.
* Wed Feb  9 2000 ke@suse.de
- add group tag.
- ./configure -> %%build.
- New default for rc.config variable START_POSTGRES ("no").
* Fri Dec 10 1999 ke@suse.de
- update: version 6.5.3.
- startup script: use -S to remove the socket.
* Tue Oct 12 1999 ro@suse.de
- added tcld to neededforbuild
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Aug  2 1999 ke@suse.de
- postgresql init script: remove the socket in /tmp before trying to
  start the postmaster.
* Thu Jul 29 1999 ke@suse.de
- update: version 6.5.1.
* Tue Jul 20 1999 ke@suse.de
- remove MANPATH setting from /etc/postgres.{sh,csh} and from
  /etc/pg_ifa.{sh,csh}.
- provide manpage links at /usr/share/man:
    /usr/lib/pgsql/man/man?/*.?.gz -> /urs/share/man/man?/*.?.pgsql.gz
- now, you'll find all manpage in "pg_ifa".
* Thu Mar 18 1999 ke@suse.de
- compile an install "spi" (on popular demand...).
* Wed Feb 10 1999 ke@suse.de
- security fix: don't create pg_pwd with mode 666 (thanks to mt).
* Mon Feb  1 1999 ke@suse.de
- fix permissions of libs (thanks to mt).
* Fri Jan  8 1999 ke@suse.de
- update: version 6.4.2.
* Tue Dec  1 1998 ke@suse.de
- add /etc/profile.d/{postgres,pg_ifa}.csh (thanks to werner).
- new bootscript (thanks to werner).
* Fri Nov 27 1998 ke@suse.de
- link libpgtcl against libcrypt.
* Thu Nov 12 1998 bs@suse.de
- fixed spec file for new rpm.
* Fri Oct 30 1998 ke@suse.de
- update: version 6.4-BETA4.
* Sun Sep 27 1998 ke@suse.de
- update: version pre6.4 (snapshot 1998-09-27).
- remove pgaccess (it's a separate package now).
- all libraries and binaries are under the separate hierarchy
  /usr/lib/pgsql (on customers' request...).
- provide /etc/profile.d/{postgres,pg_ifa}.sh; .csh files are still
  missing.
* Mon Aug 24 1998 ke@suse.de
- shut down the postmaster before uninstalling.
* Tue Aug 18 1998 ke@suse.de
- add pgaccess' GIFs (HTML documentation).
* Sat Jul 25 1998 ke@suse.de
- Use `-n postgres' to make the `%%post' script available.
* Mon Jul 13 1998 ke@suse.de
- update pgaccess: version 0.88.
* Thu May 28 1998 ke@suse.de
- New package split: rip out the base interfaces (libraries and database
  tools); the new package is called pg_ifa (subpackage).
- update pgaccess: version 0.87.
* Fri May 22 1998 ke@suse.de
- update: version 6.3.2
- package split to ease maintainability and user updates; now, we've the
  following packages:
  postgres : base packages, essential interfaces included (libpq,
  libpq++, libpqtcl and PgAccess).
  pg_datab : initial database (needed only for the first
  installation or in case of major number updates); if
  not installed, the user has to invoke `initdb'
  manually.
  pg_iface : PostgreSQL interfaces (Perl, JDBC, more to come...).
* Thu May  7 1998 fehr@suse.de
- add library -lXp for Motif 2.1
* Wed Feb 11 1998 fehr@suse.de
- added the perl interface
* Wed Dec 10 1997 ro@suse.de
- build static and dynamic version of dbbrowser and mpsql
* Wed Dec  3 1997 ro@suse.de
- fixed /sbin/init.d/postgres (path, db-path, read rc.config)
  moved logfile to /var/log
* Tue Nov 18 1997 bs@suse.de
- skipped man3/abort.3.gz
* Tue Nov  4 1997 fehr@suse.de
- changed to version 6.2.1 of the new postgresSQL
- changed to version 1.5 of mpsql
- changed to version 0.2 of AppGEN
- added version 0.9 if dbbrowser
- prepare package for automatic build
- home Directory of postgrs user must now be /var/lib/postgres
- this Change is a major step since postgres95 it is possible
  that some changes are incompatible with the previos postgres
  versions.
* Mon Jun  9 1997 fehr@suse.de
- make symbolic link in /usr/doc/packages relative
* Sun Jun  1 1997 bs@suse.de
- moved fillup stuff to var/adm/fillup-templates
* Mon May 12 1997 fehr@suse.de
- added startup-script for /sbin/init.d
- added fillup for /etc/rc.config START_POSTGRES
